@@ -7,7 +7,7 @@ from devtools import debug
 from pydantic import BaseModel, PrivateAttr
 from .execute import query as execute_query
 from .node import Node
-from .constants import ALIAS_PATTERN
+from .constants import ALIAS_PATTERN, random_str
 from .span import safe_span
 
 NodeType = T.TypeVar("NodeType", bound=Node)
@@ -236,8 +236,9 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         variables = {}
         for field_name, field_value in kwargs.items():
             cast = conversion_map[field_name]["cast"]
-            filter_strs.append(f".{field_name} = <{cast}>${field_name}")
-            variables[field_name] = field_value
+            variable_name = f"{field_name}{random_str(10)}"
+            filter_strs.append(f".{field_name} = <{cast}>${variable_name}")
+            variables[variable_name] = field_value
         filter_str = " AND ".join(filter_strs)
         return self.filter(filter_str=filter_str, variables=variables)
 
@@ -250,7 +251,7 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         variables = {}
         for field_name, value_lst in kwargs.items():
             cast = conversion_map[field_name]["cast"]
-            variable_name = f"{field_name}s"
+            variable_name = f"{field_name}s{random_str(10)}"
             filter_strs.append(
                 f".{field_name} in array_unpack(<array<{cast}>>${variable_name})"
             )
